@@ -172,12 +172,12 @@ func (x *Xlsx) createTableSheet(w *excl.Workbook, t *schema.Table) (e error) {
 		x.config.MergedDict.Lookup("Nullable"),
 	}
 	hideColumns := x.config.Format.HideColumnsWithoutValues
-	x.adjustColumnHeader(&columnValues, t.ShowColumn("ExtraDef", hideColumns), "Extra Definition")
-	x.adjustColumnHeader(&columnValues, t.ShowColumn("Occurrences", hideColumns), "Occurrences")
-	x.adjustColumnHeader(&columnValues, t.ShowColumn("Percents", hideColumns), "Percents")
-	x.adjustColumnHeader(&columnValues, t.ShowColumn("Children", hideColumns), "Children")
-	x.adjustColumnHeader(&columnValues, t.ShowColumn("Parents", hideColumns), "Parents")
-	x.adjustColumnHeader(&columnValues, t.ShowColumn("Comment", hideColumns), "Comment")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn(schema.ColumnExtraDef, hideColumns), "Extra Definition")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn(schema.ColumnOccurrences, hideColumns), "Occurrences")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn(schema.ColumnPercents, hideColumns), "Percents")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn(schema.ColumnChildren, hideColumns), "Children")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn(schema.ColumnParents, hideColumns), "Parents")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn(schema.ColumnComment, hideColumns), "Comment")
 	setHeader(sheet, 5, columnValues)
 	r := 6
 	for i, c := range t.Columns {
@@ -186,20 +186,20 @@ func (x *Xlsx) createTableSheet(w *excl.Workbook, t *schema.Table) (e error) {
 		setStringWithBorder(sheet, r+i, 3, c.Default.String)
 		setStringWithBorder(sheet, r+i, 4, fmt.Sprintf("%v", c.Nullable))
 		ci := 5
-		ci = adjustData(t.ShowColumn("ExtraDef", hideColumns), sheet, r+i, ci, fmt.Sprintf("%v", c.ExtraDef))
-		ci = adjustData(t.ShowColumn("Occurrences", hideColumns), sheet, r+i, ci, fmt.Sprintf("%d", c.Occurrences.Int32))
-		ci = adjustData(t.ShowColumn("Percent", hideColumns), sheet, r+i, ci, fmt.Sprintf("%.1f", c.Percents.Float64))
+		ci = adjustData(t.ShowColumn(schema.ColumnExtraDef, hideColumns), sheet, r+i, ci, fmt.Sprintf("%v", c.ExtraDef))
+		ci = adjustData(t.ShowColumn(schema.ColumnOccurrences, hideColumns), sheet, r+i, ci, fmt.Sprintf("%d", c.Occurrences.Int32))
+		ci = adjustData(t.ShowColumn(schema.ColumnPercents, hideColumns), sheet, r+i, ci, fmt.Sprintf("%.1f", c.Percents.Float64))
 		children := []string{}
 		for _, child := range c.ChildRelations {
 			children = append(children, child.Table.Name)
 		}
-		ci = adjustData(t.ShowColumn("Children", hideColumns), sheet, r+i, ci, strings.Join(children, "\n"))
+		ci = adjustData(t.ShowColumn(schema.ColumnChildren, hideColumns), sheet, r+i, ci, strings.Join(children, "\n"))
 		parents := []string{}
 		for _, parent := range c.ParentRelations {
 			parents = append(parents, parent.ParentTable.Name)
 		}
-		ci = adjustData(t.ShowColumn("Parents", hideColumns), sheet, r+i, ci, strings.Join(parents, "\n"))
-		ci = adjustData(t.ShowColumn("Comment", hideColumns), sheet, r+i, ci, c.Comment) //nolint
+		ci = adjustData(t.ShowColumn(schema.ColumnParents, hideColumns), sheet, r+i, ci, strings.Join(parents, "\n"))
+		ci = adjustData(t.ShowColumn(schema.ColumnComment, hideColumns), sheet, r+i, ci, c.Comment) //nolint
 	}
 	r = r + len(t.Columns)
 
